import { SourceAdapter, MetadataType, MetadataRegistry, SourcePath, TreeContainer } from '../../types';
import { ForceIgnore } from '../forceIgnore';
import { SourceComponent } from '../sourceComponent';
export declare abstract class BaseSourceAdapter implements SourceAdapter {
    protected type: MetadataType;
    protected registry: MetadataRegistry;
    protected forceIgnore: ForceIgnore;
    protected tree: TreeContainer;
    /**
     * Whether or not an adapter should expect a component to be in its own, self-named
     * folder, including its root metadata xml file.
     */
    protected ownFolder: boolean;
    constructor(type: MetadataType, registry?: MetadataRegistry, forceIgnore?: ForceIgnore, tree?: TreeContainer);
    getComponent(path: SourcePath): SourceComponent;
    /**
     * Determine the related root metadata xml when the path given to `getComponent` isn't one.
     *
     * @param trigger Path that `getComponent` was called with
     */
    protected abstract getRootMetadataXmlPath(trigger: SourcePath): SourcePath;
    /**
     * Populate additional properties on a SourceComponent, such as source files and child components.
     * The component passed to `populate` has its fullName, xml, and type properties already set.
     *
     * @param component Component to populate properties on
     * @param trigger Path that `getComponent` was called with
     */
    protected abstract populate(component: SourceComponent, trigger: SourcePath): SourceComponent;
    /**
     * If the path given to `getComponent` is the root metadata xml file for a component,
     * parse the name and return it. This is an optimization to not make a child adapter do
     * anymore work to find it.
     *
     * @param path File path of a metadata component
     */
    private parseAsRootMetadataXml;
}
