import { SourceComponent } from '../metadata-registry';
import { SourcePath } from './common';
export declare type Id = string;
export declare type ComponentDeployment = {
    id?: string;
    component: SourceComponent;
    status: ComponentStatus;
    diagnostics: ComponentDiagnostic[];
};
export declare type ComponentDiagnostic = {
    lineNumber?: number;
    columnNumber?: number;
    filePath?: SourcePath;
    message: string;
    type: 'Warning' | 'Error';
};
/**
 * Possible statuses of a component being deployed.
 */
export declare enum ComponentStatus {
    Created = "Created",
    Changed = "Changed",
    Unchanged = "Unchanged",
    Deleted = "Deleted",
    Failed = "Failed"
}
interface SourceApiResult {
    success: boolean;
}
export interface SourceDeployResult extends SourceApiResult {
    id: Id;
    components?: ComponentDeployment[];
    status: DeployStatus | ToolingDeployStatus;
}
/**
 * Raw response returned from a checkDeployStatus call to the Metadata API
 */
export declare type DeployResult = {
    id: string;
    canceledBy?: string;
    canceledByName?: string;
    checkOnly: boolean;
    completedDate?: string;
    createdBy: string;
    createdByName: string;
    createdDate: string;
    details: DeployDetails;
    done: boolean;
    errorMessage?: string;
    errorStatusCode?: string;
    ignoreWarnings: boolean;
    lastModifiedDate: string;
    numberComponentErrors: number;
    numberComponentsDeployed: number;
    numberComponentsTotal: number;
    numberTestErrors: number;
    numberTestsCompleted: number;
    numberTestsTotal: number;
    runTestsEnabled: boolean;
    rollbackOnError: boolean;
    startDate?: string;
    stateDetail?: string;
    status: DeployStatus;
    success: boolean;
};
/**
 * Possible statuses of a metadata deploy operation.
 */
export declare enum DeployStatus {
    Pending = "Pending",
    InProgress = "InProgress",
    Succeeded = "Succeeded",
    SucceededPartial = "SucceededPartial",
    Failed = "Failed",
    Canceling = "Canceling",
    Canceled = "Canceled"
}
export declare type DeployDetails = {
    componentFailures?: DeployMessage[];
    componentSuccesses?: DeployMessage[];
};
declare type BooleanString = 'true' | 'false' | true | false;
export declare type DeployMessage = {
    changed: BooleanString;
    columnNumber?: string;
    componentType?: string;
    created: BooleanString;
    createdDate: string;
    deleted: BooleanString;
    fileName: string;
    fullName: string;
    id?: string;
    lineNumber?: string;
    problem?: string;
    problemType?: 'Warning' | 'Error';
    success: BooleanString;
};
export declare type ContainerAsyncRequest = {
    Id: Id;
    DeployDetails?: DeployDetails;
    ErrorMsg?: string;
    State?: ToolingDeployStatus;
};
export declare const enum ToolingDeployStatus {
    Queued = "Queued",
    Invalidated = "Invalidated",
    Error = "Error",
    Aborted = "Aborted",
    Completed = "Completed",
    Failed = "Failed",
    CompletedPartial = "CompletedPartial"
}
export {};
